==> estateplat-common-1.2.3-20180612.130104-116-sources.jar: cn/gtmap/estateplat/model/server/core/BdcBdcZsSd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lj</a>
 * @version 1.0, 2015-05-12
 * @description 过渡数据锁定表
 */

@Table(name = "bdc_bdczssd")
public class BdcBdcZsSd implements Serializable, InsertVo {
	@Id
	private String sdid;//锁定id
	private String cqzh;//产权证号
	private String zsid;//证书ID
	private String bdclx;//不动产类型
	private String proid;//项目id
	private Integer xzzt;//限制状态
	private String xzyy;//限制原因
	private String xztype;//限制类型
	private String sdr;//锁定人
	private Date sdsj;//锁定时间
	private String jsr;//解锁人
	private Date jssj;//解锁时间
	private String jbr;//经办人
	private String jsyy;//解锁原因
    private String bz;//备注
	private Integer sdnx;//锁定年限

	public String getSdid() {
		return sdid;
	}

	public void setSdid(String sdid) {
		this.sdid = sdid;
	}

	public String getCqzh() {
		return cqzh;
	}

	public void setCqzh(String cqzh) {
		this.cqzh = cqzh;
	}

	public String getBdclx() {
		return bdclx;
	}

	public void setBdclx(String bdclx) {
		this.bdclx = bdclx;
	}

	public String getProid() {
		return proid;
	}

	public void setProid(String proid) {
		this.proid = proid;
	}

	public Integer getXzzt() {
		return xzzt;
	}

	public void setXzzt(Integer xzzt) {
		this.xzzt = xzzt;
	}

	public String getXzyy() {
		return xzyy;
	}

	public void setXzyy(String xzyy) {
		this.xzyy = xzyy;
	}

	public String getXztype() {
		return xztype;
	}

	public void setXztype(String xztype) {
		this.xztype = xztype;
	}

	public String getSdr() {
		return sdr;
	}

	public void setSdr(String sdr) {
		this.sdr = sdr;
	}

	public Date getSdsj() {
		return sdsj;
	}

	public void setSdsj(Date sdsj) {
		this.sdsj = sdsj;
	}

	public String getJsr() {
		return jsr;
	}

	public void setJsr(String jsr) {
		this.jsr = jsr;
	}

	public Date getJssj() {
		return jssj;
	}

	public void setJssj(Date jssj) {
		this.jssj = jssj;
	}

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

	public String getJbr() {
		return jbr;
	}

	public void setJbr(String jbr) {
		this.jbr = jbr;
	}

	public String getJsyy() {
		return jsyy;
	}

	public void setJsyy(String jsyy) {
		this.jsyy = jsyy;
	}

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBz() {
        return bz;
    }

	public Integer getSdnx() {
		return sdnx;
	}

	public void setSdnx(Integer sdnx) {
		this.sdnx = sdnx;
	}
}

==> estateplat-common-1.2.3-20181115.055357-211-sources.jar: cn/gtmap/estateplat/model/server/core/BdcBdcZsSd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lj</a>
 * @version 1.0, 2015-05-12
 * @description 过渡数据锁定表
 */

@Table(name = "bdc_bdczssd")
public class BdcBdcZsSd implements Serializable, InsertVo {
	@Id
	private String sdid;//锁定id
	private String cqzh;//产权证号
	private String zsid;//证书ID
	private String bdclx;//不动产类型
	private String proid;//项目id
	private Integer xzzt;//限制状态
	private String xzyy;//限制原因
	private String xztype;//限制类型
	private String sdr;//锁定人
	private Date sdsj;//锁定时间
	private String jsr;//解锁人
	private Date jssj;//解锁时间
	private String jbr;//经办人
	private String jsyy;//解锁原因
    private String bz;//备注
	private Integer sdnx;//锁定年限
	private String sdlcgzlid;//锁定流程工作流ID
	private String jslcgzlid;//解锁流程工作流ID

	public String getSdid() {
		return sdid;
	}

	public void setSdid(String sdid) {
		this.sdid = sdid;
	}

	public String getCqzh() {
		return cqzh;
	}

	public void setCqzh(String cqzh) {
		this.cqzh = cqzh;
	}

	public String getBdclx() {
		return bdclx;
	}

	public void setBdclx(String bdclx) {
		this.bdclx = bdclx;
	}

	public String getProid() {
		return proid;
	}

	public void setProid(String proid) {
		this.proid = proid;
	}

	public Integer getXzzt() {
		return xzzt;
	}

	public void setXzzt(Integer xzzt) {
		this.xzzt = xzzt;
	}

	public String getXzyy() {
		return xzyy;
	}

	public void setXzyy(String xzyy) {
		this.xzyy = xzyy;
	}

	public String getXztype() {
		return xztype;
	}

	public void setXztype(String xztype) {
		this.xztype = xztype;
	}

	public String getSdr() {
		return sdr;
	}

	public void setSdr(String sdr) {
		this.sdr = sdr;
	}

	public Date getSdsj() {
		return sdsj;
	}

	public void setSdsj(Date sdsj) {
		this.sdsj = sdsj;
	}

	public String getJsr() {
		return jsr;
	}

	public void setJsr(String jsr) {
		this.jsr = jsr;
	}

	public Date getJssj() {
		return jssj;
	}

	public void setJssj(Date jssj) {
		this.jssj = jssj;
	}

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

	public String getJbr() {
		return jbr;
	}

	public void setJbr(String jbr) {
		this.jbr = jbr;
	}

	public String getJsyy() {
		return jsyy;
	}

	public void setJsyy(String jsyy) {
		this.jsyy = jsyy;
	}

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBz() {
        return bz;
    }

	public Integer getSdnx() {
		return sdnx;
	}

	public void setSdnx(Integer sdnx) {
		this.sdnx = sdnx;
	}

	public String getSdlcgzlid() {
		return sdlcgzlid;
	}

	public void setSdlcgzlid(String sdlcgzlid) {
		this.sdlcgzlid = sdlcgzlid;
	}

	public String getJslcgzlid() {
		return jslcgzlid;
	}

	public void setJslcgzlid(String jslcgzlid) {
		this.jslcgzlid = jslcgzlid;
	}
}
